==> labmateai-1.0.0.tar.gz: labmateai-1.0.0/README.md <==
# LabMateAI

**LabMateAI** is an AI-powered recommendation system designed to help researchers discover relevant laboratory tools and software for their scientific needs. Whether you're involved in bioinformatics, genomics, data visualization, or any other scientific domain, LabMateAI makes it easy to find the right resources with simple commands.

## Table of Contents

- [Features](#features)
- [Installation](#installation)
- [Usage](#usage)
  - [1. Tool Similarity Recommendations](#1-tool-similarity-recommendations)
  - [2. Category-Based Recommendations](#2-category-based-recommendations)
  - [3. Keyword-Based Search](#3-keyword-based-search)
- [Contributing](#contributing)
- [License](#license)
- [Contact](#contact)

---

## Features

- **Tool Similarity Recommendations**: Find tools similar to a specific tool you already use.
- **Category-Based Recommendations**: Discover tools within a specific scientific category.
- **Keyword-Based Search**: Search for tools based on keywords related to your research.

---

## Installation

You can install LabMateAI using `pip`:

```bash
pip install labmateai
```

LabMateAI requires Python 3.6 or higher.

---

## Usage

After installation, you can start using LabMateAI through the command line:

```bash
labmateai
```

This will launch the interactive command-line interface (CLI), where you can choose from the following options:

### 1. Tool Similarity Recommendations

Get recommendations for tools similar to a specific tool.

**Steps**:

1. Select **Recommend tools similar to a specific tool**.
2. Enter the name of the tool (e.g., `BLAST`).
3. Specify the number of recommendations you want.

### 2. Category-Based Recommendations

Discover tools within a specific scientific category.

**Steps**:

1. Select **Recommend tools in a specific category**.
2. Enter the category name (e.g., `Genomics`).

### 3. Keyword-Based Search

Search for tools based on a keyword related to your research.

**Steps**:

1. Select **Search for tools by keyword**.
2. Enter your keyword (e.g., `RNA`).

---

## Contributing

Contributions are welcome!

If you'd like to contribute to LabMateAI, please follow these steps:

1. **Fork the repository** on GitHub.
2. **Create a new branch** for your feature or bug fix:
   ```bash
   git checkout -b feature/your-feature-name
   ```
3. **Commit your changes** with clear messages:
   ```bash
   git commit -m "Add your clear and descriptive commit message"
   ```
4. **Push to your branch**:
   ```bash
   git push origin feature/your-feature-name
   ```
5. **Create a Pull Request** on GitHub, detailing your changes.

Please refer to the [CONTRIBUTING.md](CONTRIBUTING.md) file for more detailed guidelines.

---

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.

---

## Contact

For questions or support, please contact us at [support@labmateai.io](mailto:support@labmateai.io).

---

**Disclaimer**: LabMateAI is an open-source project aimed at assisting researchers. While we strive to provide accurate and helpful recommendations, we do not endorse any specific tools or guarantee the suitability of tools for your specific needs.

---

## Acknowledgments

We would like to thank all contributors and the open-source community for their support and valuable contributions to LabMateAI.

==> labmateai-2.0.4.tar.gz: labmateai-2.0.4/README.md <==

# LabMateAI

**LabMateAI** is an AI-powered recommendation system designed to help researchers discover relevant laboratory tools and software for their scientific needs. Whether you're involved in bioinformatics, genomics, data visualization, or any other scientific domain, LabMateAI makes it easy to find the right resources with simple commands.

## Table of Contents

- [Features](#features)
- [Installation](#installation)
- [Usage](#usage)
  - [1. Tool Similarity Recommendations](#1-tool-similarity-recommendations)
  - [2. Category-Based Recommendations](#2-category-based-recommendations)
  - [3. Keyword-Based Search](#3-keyword-based-search)
- [Contributing](#contributing)
- [License](#license)
- [Contact](#contact)

---

## Features

- **Tool Similarity Recommendations**: Find tools similar to a specific tool you already use.
- **Category-Based Recommendations**: Discover tools within a specific scientific category.
- **Keyword-Based Search**: Search for tools based on keywords related to your research.

---

## Installation

You can install LabMateAI using `pip`:

```bash
pip install labmateai
```

LabMateAI requires Python 3.8 or higher.

---

## Usage

After installation, you can start using LabMateAI through the command line:

```bash
labmateai
```

This will launch the interactive command-line interface (CLI), where you can choose from the following options:

### 1. Tool Similarity Recommendations

Get recommendations for tools similar to a specific tool.

**Steps**:

1. Select **Recommend tools similar to a specific tool**.
2. Enter the name of the tool (e.g., `BLAST`).
3. Specify the number of recommendations you want.

### 2. Category-Based Recommendations

Discover tools within a specific scientific category.

**Steps**:

1. Select **Recommend tools in a specific category**.
2. Enter the category name (e.g., `Genomics`).

### 3. Keyword-Based Search

Search for tools based on a keyword related to your research.

**Steps**:

1. Select **Search for tools by keyword**.
2. Enter your keyword (e.g., `RNA`).

---

## Contributing

Contributions are welcome!

If you'd like to contribute to LabMateAI, please follow these steps:

1. **Fork the repository** on GitHub.
2. **Create a new branch** for your feature or bug fix:
   ```bash
   git checkout -b feature/your-feature-name
   ```
3. **Commit your changes** with clear messages:
   ```bash
   git commit -m "Add your clear and descriptive commit message"
   ```
4. **Push to your branch**:
   ```bash
   git push origin feature/your-feature-name
   ```
5. **Create a Pull Request** on GitHub, detailing your changes.

Please refer to the [CONTRIBUTING.md](CONTRIBUTING.md) file for more detailed guidelines.

---

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.

---

## Contact

For questions or support, please [contact us.](mailto:tnoblin@health.ucsd.edu).

---

**Disclaimer**: LabMateAI is an open-source project aimed at assisting researchers. While we strive to provide accurate and helpful recommendations, we do not endorse any specific tools or guarantee the suitability of tools for your specific needs.

---

## Acknowledgments

We would like to thank all contributors and the open-source community for their support and valuable contributions to LabMateAI.
